@@ -68,31 +68,38 @@ epilog="""example uses:
   ropper.py --file /bin/ls --console
 
   [Informations]
-  ropper.py --file /bin/ls --info
-  ropper.py --file /bin/ls --imports
-  ropper.py --file /bin/ls --sections
-  ropper.py --file /bin/ls --segments
-  ropper.py --file /bin/ls --set nx
-  ropper.py --file /bin/ls --unset nx
+  Ropper.py --file /bin/ls --info
+  Ropper.py --file /bin/ls --imports
+  Ropper.py --file /bin/ls --sections
+  Ropper.py --file /bin/ls --segments
+  Ropper.py --file /bin/ls --set nx
+  Ropper.py --file /bin/ls --unset nx
 
   [Gadgets]
-  ropper.py --file /bin/ls --inst-count 5
-  ropper.py --file /bin/ls --search "sub eax" --badbytes 000a0d
-  ropper.py --file /bin/ls --search "sub eax" --detail
-  ropper.py --file /bin/ls --filter "sub eax"
-  ropper.py --file /bin/ls --inst-count 5 --filter "sub eax"
-  ropper.py --file /bin/ls --opcode ffe4
-  ropper.py --file /bin/ls --opcode ffe?
-  ropper.py --file /bin/ls --opcode ??e4
-  ropper.py --file /bin/ls --detailed
-  ropper.py --file /bin/ls --ppr --nocolor
-  ropper.py --file /bin/ls --jmp esp,eax
-  ropper.py --file /bin/ls --type jop
-  ropper.py --file /bin/ls --chain execve=/bin/sh
-  ropper.py --file /bin/ls --chain execve=/bin/sh --badbytes 000a0d
-  ropper.py --file /bin/ls --chain mprotect=0xbfdff000:0x21000
+  Ropper.py --file /bin/ls --inst-count 5
+  Ropper.py --file /bin/ls --search "sub eax" --badbytes 000a0d
+  Ropper.py --file /bin/ls --search "sub eax" --detail
+  Ropper.py --file /bin/ls --filter "sub eax"
+  Ropper.py --file /bin/ls --inst-count 5 --filter "sub eax"
+  Ropper.py --file /bin/ls --opcode ffe4
+  Ropper.py --file /bin/ls --opcode ffe?
+  Ropper.py --file /bin/ls --opcode ??e4
+  Ropper.py --file /bin/ls --detailed
+  Ropper.py --file /bin/ls --ppr --nocolor
+  Ropper.py --file /bin/ls --jmp esp,eax
+  Ropper.py --file /bin/ls --type jop
+  Ropper.py --file /bin/ls --chain execve
+  Ropper.py --file /bin/ls --chain execve=/bin/sh
+  Ropper.py --file /bin/ls --chain execve=/bin/sh --badbytes 000a0d
+  Ropper.py --file /bin/ls --chain mprotect=0xbfdff000:0x21000
+
+  [Assemble/Disassemble]
+  Ropper.py --asm "jmp esp"
+  Ropper.py --asm "mov eax, ecx; ret"
+  Ropper.py --disasm ffe4
 
   [Search]
+  Ropper.py --file /bin/ls --search <searchstring>
   ?\t\tany character
   %\t\tany string
 
@@ -134,7 +141,11 @@ epilog="""example uses:
         parser.add_argument(
             '--hex', help='Prints the selected sections in a hex format', action='store_true')
         parser.add_argument(
-            '--disassemble', help='Disassembles instruction at address <address> (0x12345678:L3). The count of instructions to disassemble can be specified (0x....:L...)', metavar='<address:length>')
+            '--asm', help='A string to assemble and a format of the output (H=HEX, S=STRING, R=RAW, default: H)', nargs='+', metavar="<asm> [H|S|R]")
+        parser.add_argument(
+            '--disasm', help='Opcode to disassemble (e.g. ffe4, 89c8c3, ...)', metavar="<opcode>")
+        parser.add_argument(
+            '--disassemble-address', help='Disassembles instruction at address <address> (0x12345678:L3). The count of instructions to disassemble can be specified (0x....:L...)', metavar='<address:length>')
         parser.add_argument(
             '-i', '--info', help='Shows file header [ELF/PE/Mach-O]', action='store_true')
         parser.add_argument('-e', help='Shows EntryPoint', action='store_true')
@@ -163,7 +174,7 @@ epilog="""example uses:
         parser.add_argument(
             '--stack-pivot', help='Prints all stack pivot gadgets',action='store_true')
         parser.add_argument(
-            '--inst-count', help='Specifies the max count of instructions in a gadget (default: 10)', metavar='<n bytes>', type=int, default=5)
+            '--inst-count', help='Specifies the max count of instructions in a gadget (default: 6)', metavar='<n bytes>', type=int, default=6)
         parser.add_argument(
             '--search', help='Searches for gadgets', metavar='<regex>')
         parser.add_argument(
@@ -172,6 +183,8 @@ epilog="""example uses:
             '--filter', help='Filters gadgets', metavar='<regex>')
         parser.add_argument(
             '--opcode', help='Searchs for opcodes (e.g. ffe4 or ffe? or ff??)', metavar='<opcode>')
+        parser.add_argument(
+            '--instructions', help='Searchs for instructions (e.g. "jmp esp", "pop eax; ret")', metavar='<instructions>')
         parser.add_argument(
             '--type', help='Sets the type of gadgets [rop, jop, sys, all] (default: all)', metavar='<type>', default='all')
         parser.add_argument(
@@ -194,7 +207,7 @@ epilog="""example uses:
 
         self.nocolor = self.__args.nocolor and not self.isWindows()
 
-        if not self.__args.console and not self.__args.file and not self.__args.version:
+        if not self.__args.asm and not self.disasm and not self.__args.console and not self.__args.file and not self.__args.version:
             self.__missingArgument('[-f|--file]')
 
         if self.__args.I:
